summaryrefslogtreecommitdiff
path: root/sleekxmpp/plugins/xep_0030/disco.py
diff options
context:
space:
mode:
authorLance Stout <lancestout@gmail.com>2010-12-16 23:52:17 -0500
committerLance Stout <lancestout@gmail.com>2010-12-16 23:52:17 -0500
commit53a5026301b6f6e842fa29b52bef1721e068eddf (patch)
tree3266574dc6cd6b84edcb990eefebfdfbf3303351 /sleekxmpp/plugins/xep_0030/disco.py
parent0aee445e6976b03f7e04bcab6ec40ecf14b5d1a4 (diff)
downloadslixmpp-53a5026301b6f6e842fa29b52bef1721e068eddf.tar.gz
slixmpp-53a5026301b6f6e842fa29b52bef1721e068eddf.tar.bz2
slixmpp-53a5026301b6f6e842fa29b52bef1721e068eddf.tar.xz
slixmpp-53a5026301b6f6e842fa29b52bef1721e068eddf.zip
Almost done with xep-30; added more docs.
Diffstat (limited to 'sleekxmpp/plugins/xep_0030/disco.py')
-rw-r--r--sleekxmpp/plugins/xep_0030/disco.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/sleekxmpp/plugins/xep_0030/disco.py b/sleekxmpp/plugins/xep_0030/disco.py
index ad3d0ae2..1b78d522 100644
--- a/sleekxmpp/plugins/xep_0030/disco.py
+++ b/sleekxmpp/plugins/xep_0030/disco.py
@@ -230,7 +230,7 @@ class xep_0030(base_plugin):
no stanzas need to be sent.
Otherwise, a disco stanza must be sent to the
remove JID to retrieve the info.
dfrom -- Specifiy the sender's JID.
block -- If true, block and wait for the stanzas' reply.
timeout -- The time in seconds to block while waiting for
a reply. If None, then wait indefinitely.
@@ -245,7 +245,7 @@ class xep_0030(base_plugin):
return self._fix_default_info(info)
iq = self.xmpp.Iq()
- iq['from'] = kwargs.get('dfrom', '')
+ iq['from'] = kwargs.get('ifrom', '')
iq['to'] = jid
iq['type'] = 'get'
iq['disco_info']['node'] = node if node else ''
@@ -270,7 +270,7 @@ class xep_0030(base_plugin):
no stanzas need to be sent.
Otherwise, a disco stanza must be sent to the
remove JID to retrieve the items.
dfrom -- Specifiy the sender's JID.
block -- If true, block and wait for the stanzas' reply.
timeout -- The time in seconds to block while waiting for
a reply. If None, then wait indefinitely.
@@ -282,7 +282,7 @@ class xep_0030(base_plugin):
return self._run_node_handler('get_items', jid, node, kwargs)
iq = self.xmpp.Iq()
- iq['from'] = kwargs.get('dfrom', '')
+ iq['from'] = kwargs.get('ifrom', '')
iq['to'] = jid
iq['type'] = 'get'
iq['disco_items']['node'] = node if node else ''
@@ -230,7 +230,7 @@ class xep_0030(base_plugin):
Otherwise, a disco stanza must be sent to the
remove JID to retrieve the info.
- dfrom -- Specifiy the sender's JID.
+ ifrom -- Specifiy the sender's JID.
block -- If true, block and wait for the stanzas' reply.
timeout -- The time in seconds to block while waiting for
@@ -270,7 +270,7 @@ class xep_0030(base_plugin):
Otherwise, a disco stanza must be sent to the
remove JID to retrieve the items.
- dfrom -- Specifiy the sender's JID.
+ ifrom -- Specifiy the sender's JID.
block -- If true, block and wait for the stanzas' reply.
timeout -- The time in seconds to block while waiting for